Changelog
=========


0.2.2 (2021-08-17)
------------------

- Fix breadcrumbs and pagination in ReferenceField.
  [cekk]


0.2.1 (2021-05-18)
------------------

- Add alt text on buttons
- Add locales for a11y hints
  [nzambello]


0.2.0 (2021-05-17)
------------------

- Add link and path to referenced items
  [nzambello]
- Fix TextLine field.
  [cekk]

0.1.0 (2021-02-09)
------------------

- Initial release.
  [cekk]
